@@ -3,7 +3,12 @@ NULL
 
 #' S4 textstat class
 #' 
-#' superclass for comp and context class
+#' Superclass for features, context, and partition class.
+#' 
+#' Objects derived from the \code{textstat} class can be indexed with simple
+#' square brackets ("[") to get rows specified by an numeric/integer vector,
+#' and with double square brackets ("[[") to get specific columns from the 
+#' \code{data.table} in the slot \code{stat}.
 #' 
 #' @slot pAttribute Object of class \code{"character"} p-attribute of the query
 #' @slot corpus Object of class \code{"character"}
@@ -16,7 +21,8 @@ NULL
 #' @param decreasing logical
 #' @param e1 object 1
 #' @param e2 object 2
-#' @param i index
+#' @param i vector to index data.table in stat-slot
+#' @param j vector to index data.table in stat-slot
 #' @param ... further parameters
 #' @aliases as.data.frame,textstat-method show,textstat-method
 #'   dim,textstat-method
@@ -24,18 +30,28 @@ NULL
 #'   as.DataTables,textstat-method
 #' @docType class
 #' @exportClass textstat
+#' @examples
+#' \dontrun{
+#' use("polmineR.sampleCorpus")
+#' P <- partition("PLPRBTTXT", text_year = "2009", pAttribute = "word")
+#' y <- cooccurrences(P, query = "Arbeit")
+#' y[1:25]
+#' y[,c("word", "ll")]
+#' y[1:25, "word"]
+#' y[1:25][["word"]]
+#' y[which(y[["word"]] %in% c("Arbeit", "Sozial"))]
+#' y[ y[["word"]] %in% c("Arbeit", "Sozial") ]
+#' }
 setClass("textstat",
          representation(
-           corpus="character",
-           pAttribute="character",
-           encoding="character",
-           stat="data.table",
-           name="character"
+           corpus = "character",
+           pAttribute = "character",
+           encoding = "character",
+           stat = "data.table",
+           name = "character"
          )
 )
 
-#' @exportMethod as.data.frame
-setMethod("as.data.frame", "textstat", function(x, ...) as.data.frame(x@stat))
 
 #' @exportMethod head
 #' @rdname textstat-class
@@ -116,6 +132,11 @@ setMethod("subset", "textstat", function(x, ...){
 #' @rdname textstat-class
 setMethod("as.data.table", "textstat", function(x) x@stat)
 
+#' @exportMethod as.data.frame
+#' @rdname textstat-class
+setMethod("as.data.frame", "textstat", function(x) as.data.frame(x@stat) )
+
+
 #' @exportMethod pAttribute
 #' @param object a textstat object
 #' @rdname pAttribute-method
@@ -123,12 +144,24 @@ setMethod("pAttribute", "textstat", function(object) object@pAttribute)
 
 #' @exportMethod [[
 #' @rdname textstat-class
-setMethod("[[", "textstat", function(x,i){
+setMethod("[[", "textstat", function(x, i){
+  if (nrow(x@stat) == 0){
+    warning("indexing is pointless because data.table is empty")
+  }
   x@stat[[i]]
 })
 
 #' @exportMethod [[
 #' @rdname textstat-class
-setMethod("[", "textstat", function(x,i){
-  x@stat[i]
+setMethod("[", "textstat", function(x, i, j){
+  if (nrow(x@stat) == 0){
+    warning("indexing is pointless because data.table is empty")
+  }
+  if (missing(j)){
+    x@stat <- copy(x@stat[i = i])
+  } else {
+    x@stat <- copy(x@stat[i = i, j = j, with = FALSE])
+  }
+  x
 })
+
